/**
 * Copyright 2008 Devon Hillard (devon@digitalsanctuary.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.digitalsanctuary.atg.crypto;

/**
 * A simple class for performing encryption/decryption operations using the AES cipher.
 * 
 * @author Devon Hillard
 */
public class AESEncryptor extends AbstractEncryptor {
    /**
     * Generated serial version UID.
     */
    private static final long serialVersionUID = 536714502387566490L;

    /**
     * AES encryption algorithm.
     */
    private static final String ALGORITHM = "AES";

    /**
     * @param pKey
     *                the byte[] key which should be used to instantiate the encryptor.
     * @throws EncryptorException
     *                 if the encryptor cannot be instantiated using the key and algorithm provided.
     */
    public AESEncryptor(final byte[] pKey) throws EncryptorException {
	super(pKey);
    }

    /**
     * @param pKey
     *                the String key which should be used to instantiate the encryptor.
     * @throws EncryptorException
     *                 if the encryptor cannot be instantiated using the key and algorithm provided.
     */
    public AESEncryptor(final String pKey) throws EncryptorException {
	super(pKey);
    }

    /**
     * Returns the name of the algorithm this encryptor should use.
     * 
     * @return "AES"
     */
    protected String getAlgorithmName() {
	return ALGORITHM;
    }
}
