/**
 * Copyright 2008 Devon Hillard (devon@digitalsanctuary.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.digitalsanctuary.atg.crypto;

import java.io.Serializable;

import atg.core.util.Base64;

/**
 * This is a Dynamo component which provides AES encryption and decryption functionality.
 * 
 * @author Devon Hillard
 */
public class AESEncryptorComponent extends AbstractEncryptorComponent implements Serializable {

    /**
     * generated serial version uid.
     */
    private static final long serialVersionUID = 5899614270931897833L;

    /**
     * This method sets up the AES Encryptor.
     * 
     * @see com.online.crypto.AbstractEncryptorComponent#setupEncryptor()
     * @throws EncryptorException
     *                 if the encryptor could not be setup.
     */
    public void setupEncryptor() throws EncryptorException {
	final byte[] keyBytes = Base64.decodeToByteArray(getKey());
	setEncryptor(new AESEncryptor(keyBytes));
    }
}
