/**
 * Copyright 2008 Devon Hillard (devon@digitalsanctuary.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.digitalsanctuary.atg.crypto;

import java.security.NoSuchAlgorithmException;

import javax.crypto.KeyGenerator;
import javax.crypto.SecretKey;

import atg.core.util.Base64;

/**
 * @author Devon Hillard
 */
public class AESKeyGen {

    /**
     * @param pArgs
     *                command line arguments passed in.
     */
    public static void main(final String[] pArgs) {

	try {
	    // Get the KeyGenerator
	    final KeyGenerator kgen = KeyGenerator.getInstance("AES");
	    kgen.init(256); // 192 and 128 bits may be available
	    // Generate the secret key specs.
	    final SecretKey skey = kgen.generateKey();
	    final byte[] raw = skey.getEncoded();
	    String base64Key = Base64.encodeToString(raw);
	    System.out.println("Base64 Encoded Key: " + base64Key);

	} catch (final NoSuchAlgorithmException e) {
	    // TODO Auto-generated catch block
	    e.printStackTrace();
	}
    }

    public static String asHex(final byte[] pByteArray) {
	final StringBuffer strbuf = new StringBuffer(pByteArray.length * 2);
	int i;
	for (i = 0; i < pByteArray.length; i++) {
	    if ((pByteArray[i] & 0xff) < 0x10) {
		strbuf.append("0");
	    }
	    strbuf.append(Long.toString(pByteArray[i] & 0xff, 16));
	}
	return strbuf.toString();
    }
}
