/**
 * Copyright 2008 Devon Hillard (devon@digitalsanctuary.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.digitalsanctuary.atg.util;

import java.util.Comparator;

/**
 * This comparator can be used to Sort Strings based on their length. If used for sorting a collection of Strings it
 * will order them from longest to shortest. Note: this comparator imposes orderings that are inconsistent with equals.
 * 
 *  @author Devon Hillard devon@digitalsanctuary.com copyright 2008 DigitalSanctuary Inc. All Rights Reserved.
 * 
 */
public class StringLengthReverseComparator implements Comparator {

    /**
     * This comparator can be used to Sort Strings based on their length. Note: this comparator imposes orderings that
     * are inconsistent with equals.
     * 
     * @param pStringOne
     *                the first String to Compare.
     * @param pStringTwo
     *                the second String to Compare.
     * @return a negative integer, zero, or a positive integer as the first String is longer than than, equal to, or
     *         shorter than the second.
     * @throws ClassCastException
     *                 if either argument cannot be cast to a String.
     * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
     */
    public int compare(final Object pStringOne, final Object pStringTwo) {
	final int lengthOne = ((String) pStringOne).length();
	final int lengthTwo = ((String) pStringTwo).length();
	return lengthTwo - lengthOne;
    }
}
